Enum dot_parser::ast::AttrStmt [−][src]
pub enum AttrStmt<'a, A = (&'a str, &'a str)> {
Graph(AttrList<'a, A>),
Node(AttrList<'a, A>),
Edge(AttrList<'a, A>),
}Expand description
An attribute statement. This corresponds to the rule attr_stmt
non-terminal of the grammar.
Variants
Graph(AttrList<'a, A>)An AttrStmt on the whole graph.
Tuple Fields of Graph
0: AttrList<'a, A>Node(AttrList<'a, A>)An AttrStmt on each nodes of the graph.
Tuple Fields of Node
0: AttrList<'a, A>Edge(AttrList<'a, A>)An AttrStmt on each edges of the graph.
Tuple Fields of Edge
0: AttrList<'a, A>Trait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more