Enum dot_parser::ast::Port [−][src]
This enum corresponds to the port non-terminal of the grammar.
Variants
The variant in which an ID is given, and possibly a compass point.
Compass(CompassPt)The variant in which only a compass point is given.
Tuple Fields of Compass
0: CompassPtTrait Implementations
This method returns an ordering between self and other values if one exists. Read more
This method tests less than (for self and other) and is used by the < operator. Read more
This method tests less than or equal to (for self and other) and is used by the <=
operator. Read more
This method tests greater than (for self and other) and is used by the > operator. Read more