pub struct Edge<'a, A> {
pub from: &'a str,
pub to: &'a str,
pub attr: AList<'a, A>,
}
A single edge of the graph.
The name of the origin of the edge.
The name of the destination of the edge.
A list of attributes that apply to this specific edge.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.