pub struct Node<'a, A> {
pub id: &'a str,
pub port: Option<Port<'a>>,
pub attr: AList<'a, A>,
}
A single node of the graph.
The identifier of the node.
The attributes that apply to this node.
Formats the value using the given formatter. Read more
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.