pub enum AttrStmt<A> {
    Graph(A),
    Node(A),
    Edge(A),
}
An AttrStmt, i.e. a statement that applies to either the whole graph, all edges, or all nodes. Note that, in a canonical graph, AttrStmts contain a single statement.

Variants

Graph(A)

An AttrStmt that applies to the whole graph.

Node(A)

An AttrStmt that applies to all nodes of the graph.

Edge(A)

An AttrStmt that applies to all edges of the graph.