Enum dot_parser::canonical::AttrStmt[][src]

pub enum AttrStmt<A> {
    Graph(A),
    Node(A),
    Edge(A),
}
An AttrStmt, i.e. a statement that applies to either the whole graph, all edges, or all nodes. Note that, in a canonical graph, AttrStmts contain a single statement.

Variants

Graph(A)

An AttrStmt that applies to the whole graph.

Tuple Fields of Graph

0: A
Node(A)

An AttrStmt that applies to all nodes of the graph.

Tuple Fields of Node

0: A
Edge(A)

An AttrStmt that applies to all edges of the graph.

Tuple Fields of Edge

0: A